﻿using Chapter16.Common;
using System;
using System.Collections.Generic;
using System.IO;
using System.Linq;
using System.Runtime.InteropServices.WindowsRuntime;
using Windows.Foundation;
using Windows.Foundation.Collections;
using Windows.UI.Xaml;
using Windows.UI.Xaml.Controls;
using Windows.UI.Xaml.Controls.Primitives;
using Windows.UI.Xaml.Data;
using Windows.UI.Xaml.Input;
using Windows.UI.Xaml.Media;
using Windows.UI.Xaml.Navigation;
using Windows.Storage;
using Windows.Storage.Search;
using Windows.Storage.Pickers;
using Windows.Storage.Streams;
using Windows.UI.Xaml.Media.Imaging;
using System.Threading.Tasks;

// The Basic Page item template is documented at http://go.microsoft.com/fwlink/?LinkId=234237

namespace Chapter16
{
    /// <summary>
    /// A basic page that provides characteristics common to most applications.
    /// </summary>
    public sealed partial class MainPage : Page
    {

        private NavigationHelper navigationHelper;
        private ObservableDictionary defaultViewModel = new ObservableDictionary();

        
        public ObservableDictionary DefaultViewModel
        {
            get { return this.defaultViewModel; }
        }

       
        public NavigationHelper NavigationHelper
        {
            get { return this.navigationHelper; }
        }


        public MainPage()
        {
            this.InitializeComponent();
            this.navigationHelper = new NavigationHelper(this);
            this.navigationHelper.LoadState += navigationHelper_LoadState;
            this.navigationHelper.SaveState += navigationHelper_SaveState;
        }

      
        private async void navigationHelper_LoadState(object sender, LoadStateEventArgs e)
        {
            //If the application is launched from an image file, display it.
            //Else, if an image file has been previously saved in Local Settings, display it.
            StorageFile imageFile = e.NavigationParameter as StorageFile;
            if (imageFile != null)
            {
                await SetSource(imageFile);
            }
            else
            {
                ApplicationDataContainer localSettings = ApplicationData.Current.LocalSettings;
                if (localSettings.Values["imageSource"] != null)
                {
                    string filePath = (string)localSettings.Values["imageSource"];
                    imageFile = await StorageFile.GetFileFromPathAsync(filePath);
                    await SetSource(imageFile);
                }
            }
        }

       
        private void navigationHelper_SaveState(object sender, SaveStateEventArgs e)
        {
        }

        #region NavigationHelper registration

        /// The methods provided in this section are simply used to allow
        /// NavigationHelper to respond to the page's navigation methods.
        /// 
        /// Page specific logic should be placed in event handlers for the  
        /// <see cref="GridCS.Common.NavigationHelper.LoadState"/>
        /// and <see cref="GridCS.Common.NavigationHelper.SaveState"/>.
        /// The navigation parameter is available in the LoadState method 
        /// in addition to page state preserved during an earlier session.

        protected override void OnNavigatedTo(NavigationEventArgs e)
        {
            navigationHelper.OnNavigatedTo(e);
        }

        protected override void OnNavigatedFrom(NavigationEventArgs e)
        {
            navigationHelper.OnNavigatedFrom(e);
        }

        #endregion

        //Display a specific image that is located in the Pictures Library
        private async void Button_Click(object sender, RoutedEventArgs e)
        {
            StorageFolder picFolder = KnownFolders.PicturesLibrary;
            StorageFile logoFile = await picFolder.GetFileAsync("FluentLogo.png"); //Add a picture with this name to PicturesLibrary first!!!
            await SetSource(logoFile);
        }

        //Display image file and save image in Local Settings
        private async Task SetSource(StorageFile file)
        {
            if (file != null)
            {
                BitmapImage bitmap = new BitmapImage();
                using (IRandomAccessStream fileStream = await file.OpenAsync(FileAccessMode.Read))
                {
                    await bitmap.SetSourceAsync(fileStream);
                    logoImage.Source = bitmap;
                }

                ApplicationDataContainer localSettings = ApplicationData.Current.LocalSettings;
                localSettings.Values["imageSource"] = file.Path;
            }
        }

        //Use File Picker to retrieve image.  Display it and save in Local Settings
        private async void Button_Click_1(object sender, RoutedEventArgs e)
        {
            FileOpenPicker picker = new FileOpenPicker();
            picker.ViewMode = PickerViewMode.Thumbnail;
            picker.SuggestedStartLocation = PickerLocationId.PicturesLibrary;
            picker.FileTypeFilter.Add(".png");
            picker.FileTypeFilter.Add(".jpg");
            StorageFile file = await picker.PickSingleFileAsync();
            await SetSource(file);
        }

        //Use the Folder Picker to query its contents
        private async void Button_Click_2(object sender, RoutedEventArgs e)
        {
            FolderPicker picker = new FolderPicker();
            picker.ViewMode = PickerViewMode.Thumbnail;
            picker.SuggestedStartLocation = PickerLocationId.PicturesLibrary;
            picker.FileTypeFilter.Add(".jpg");
            picker.FileTypeFilter.Add(".png");
            StorageFolder folder = await picker.PickSingleFolderAsync();
            DefaultViewModel["folder"] = folder;
        }

        //Query the contents of the Pictures Library
        private async void Button_Click_3(object sender, RoutedEventArgs e)
        {
            StorageFolder folder = KnownFolders.PicturesLibrary;
            StorageFolderQueryResult result =
            folder.CreateFolderQuery(CommonFolderQuery.GroupByType);
            IReadOnlyList<StorageFolder> folderList = await result.GetFoldersAsync();
            System.Text.StringBuilder sb = new System.Text.StringBuilder();
            foreach (StorageFolder f in folderList)
            {
                IReadOnlyList<StorageFile> fileList = await f.GetFilesAsync();
                sb.AppendLine(f.Name + "s: " + fileList.Count.ToString());
            }
            QueryText.Text = sb.ToString();
        }
    }
}
