﻿Public NotInheritable Class ColorBrowser
    Inherits Page

    ''' <summary>
    ''' NavigationHelper is used on each page to aid in navigation and 
    ''' process lifetime management
    ''' </summary>
    Public ReadOnly Property NavigationHelper As Common.NavigationHelper
        Get
            Return Me._navigationHelper
        End Get
    End Property
    Private _navigationHelper As Common.NavigationHelper

    ''' <summary>
    ''' This can be changed to a strongly typed view model.
    ''' </summary>
    Public ReadOnly Property DefaultViewModel As Common.ObservableDictionary
        Get
            Return App.ColorViewModel
        End Get
    End Property
    Private _defaultViewModel As New Common.ObservableDictionary()

    Public Sub New()
        InitializeComponent()
        Me._navigationHelper = New Common.NavigationHelper(Me)
        AddHandler Me._navigationHelper.LoadState, AddressOf NavigationHelper_LoadState
        AddHandler Me._navigationHelper.SaveState, AddressOf NavigationHelper_SaveState
        AddHandler Me.Loaded, AddressOf DisplayFavorite
    End Sub

    Private Sub NavigationHelper_LoadState(sender As Object, e As Common.LoadStateEventArgs)

    End Sub

#Region "NavigationHelper registration"

    ''' The methods provided in this section are simply used to allow
    ''' NavigationHelper to respond to the page's navigation methods.
    ''' 
    ''' Page specific logic should be placed in event handlers for the  
    ''' <see cref="Common.NavigationHelper.LoadState"/>
    ''' and <see cref="Common.NavigationHelper.SaveState"/>.
    ''' The navigation parameter is available in the LoadState method 
    ''' in addition to page state preserved during an earlier session.

    Protected Overrides Sub OnNavigatedTo(e As NavigationEventArgs)
        _navigationHelper.OnNavigatedTo(e)
    End Sub

    Protected Overrides Sub OnNavigatedFrom(e As NavigationEventArgs)
        _navigationHelper.OnNavigatedFrom(e)
    End Sub

#End Region

    Private Sub DisplayFavorite(sender As Object, e As RoutedEventArgs)
        itemsViewSource.View.MoveCurrentTo(App.ColorViewModel("FavoriteColor"))
        itemGridView.ScrollIntoView(App.ColorViewModel("FavoriteColor"))
    End Sub

    Private Sub backButton_Click(sender As Object, e As RoutedEventArgs)
        Dim CurrentColor As ColorDetails = CType(itemsViewSource.View.CurrentItem,  _
            ColorDetails)
        App.ColorViewModel("FavoriteColor") = CurrentColor
        App.ColorViewModel("FavoriteColorBrush") = New SolidColorBrush(CurrentColor.ActualColor)
        Me.Frame.Navigate(GetType(HomePage))
    End Sub

    Private Sub NavigationHelper_SaveState(sender As Object, e As Common.SaveStateEventArgs)
    End Sub

End Class
