﻿Imports Windows.UI.Notifications
Imports Windows.Data.Xml.Dom

Public NotInheritable Class MainPage
    Inherits Page

    ''' <summary>
    ''' NavigationHelper is used on each page to aid in navigation and 
    ''' process lifetime management
    ''' </summary>
    Public ReadOnly Property NavigationHelper As Common.NavigationHelper
        Get
            Return Me._navigationHelper
        End Get
    End Property
    Private _navigationHelper As Common.NavigationHelper

    ''' <summary>
    ''' This can be changed to a strongly typed view model.
    ''' </summary>
    Public ReadOnly Property DefaultViewModel As Common.ObservableDictionary
        Get
            Return Me._defaultViewModel
        End Get
    End Property
    Private _defaultViewModel As New Common.ObservableDictionary()

    Public Sub New()

        InitializeComponent()
        Me._navigationHelper = New Common.NavigationHelper(Me)
        AddHandler Me._navigationHelper.LoadState, AddressOf NavigationHelper_LoadState
        AddHandler Me._navigationHelper.SaveState, AddressOf NavigationHelper_SaveState
    End Sub

    ''' <summary>
    ''' Populates the page with content passed during navigation.  Any saved state is also
    ''' provided when recreating a page from a prior session.
    ''' </summary>
    ''' <param name="sender">
    ''' The source of the event; typically <see cref="NavigationHelper"/>
    ''' </param>
    ''' <param name="e">Event data that provides both the navigation parameter passed to
    ''' <see cref="Frame.Navigate"/> when this page was initially requested and
    ''' a dictionary of state preserved by this page during an earlier
    ''' session.  The state will be null the first time a page is visited.</param>
    Private Sub NavigationHelper_LoadState(sender As Object, e As Common.LoadStateEventArgs)

    End Sub

    ''' <summary>
    ''' Preserves state associated with this page in case the application is suspended or the
    ''' page is discarded from the navigation cache.  Values must conform to the serialization
    ''' requirements of <see cref="Common.SuspensionManager.SessionState"/>.
    ''' </summary>
    ''' <param name="sender">
    ''' The source of the event; typically <see cref="NavigationHelper"/>
    ''' </param>
    ''' <param name="e">Event data that provides an empty dictionary to be populated with 
    ''' serializable state.</param>
    Private Sub NavigationHelper_SaveState(sender As Object, e As Common.SaveStateEventArgs)

    End Sub

#Region "NavigationHelper registration"

    ''' The methods provided in this section are simply used to allow
    ''' NavigationHelper to respond to the page's navigation methods.
    ''' 
    ''' Page specific logic should be placed in event handlers for the  
    ''' <see cref="Common.NavigationHelper.LoadState"/>
    ''' and <see cref="Common.NavigationHelper.SaveState"/>.
    ''' The navigation parameter is available in the LoadState method 
    ''' in addition to page state preserved during an earlier session.

    Protected Overrides Sub OnNavigatedTo(e As NavigationEventArgs)
        _navigationHelper.OnNavigatedTo(e)
    End Sub

    Protected Overrides Sub OnNavigatedFrom(e As NavigationEventArgs)
        _navigationHelper.OnNavigatedFrom(e)
    End Sub

#End Region


    Private Sub Button_Click(sender As Object, e As RoutedEventArgs)
        Me.Frame.Navigate(GetType(Secondary))
    End Sub

    'Update tile with message
    Private Sub Button_Click_1(sender As Object, e As RoutedEventArgs)
        Dim wideTile As XmlDocument =
            TileUpdateManager.GetTemplateContent(TileTemplateType.TileWide310x150ImageAndText02)
        Dim textNodes As XmlNodeList = wideTile.GetElementsByTagName("text")
        textNodes(0).InnerText = "Your author has something to say"
        textNodes(1).InnerText = "Again"
        Dim imageNodes As XmlNodeList = wideTile.GetElementsByTagName("image")
        Dim node As XmlElement = DirectCast(imageNodes(0), XmlElement)
        node.SetAttribute("src", "ms-appx:///Assets/Wide310x150Logo.png")
        node.SetAttribute("alt", "your author")
        Dim binding As XmlNodeList = wideTile.GetElementsByTagName("binding")
        node = DirectCast(binding(0), XmlElement)
        node.SetAttribute("branding", "logo")

        Dim squareTile As XmlDocument =
            TileUpdateManager.GetTemplateContent(TileTemplateType.TileSquare150x150PeekImageAndText04)
        textNodes = squareTile.GetElementsByTagName("text")
        textNodes(0).InnerText = "Your author has something to say. Again."
        imageNodes = squareTile.GetElementsByTagName("image")
        node = DirectCast(imageNodes(0), XmlElement)
        node.SetAttribute("src", "ms-appx:///Assets/Square150x150Logo.png")
        node.SetAttribute("alt", "your author")
        binding = squareTile.GetElementsByTagName("binding")
        node = DirectCast(binding(0), XmlElement)
        node.SetAttribute("branding", "none")

        Dim bindingNode As IXmlNode = wideTile.ImportNode(binding(0), True)
        wideTile.GetElementsByTagName("visual").Item(0).AppendChild(bindingNode)

        Dim tn As TileNotification = New TileNotification(wideTile)
        TileUpdateManager.CreateTileUpdaterForApplication().Update(tn)
    End Sub

    'Send Badge to tile
    Private Sub BadgeButton_Click(sender As Object, e As RoutedEventArgs)
        Dim badgeXML As XmlDocument =
            BadgeUpdateManager.GetTemplateContent(BadgeTemplateType.BadgeGlyph)
        Dim badgetElement As XmlElement =
            DirectCast(badgeXML.SelectSingleNode("/badge"), XmlElement)
        badgetElement.SetAttribute("value", "alert")

        Dim bn As BadgeNotification = New BadgeNotification(badgeXML)
        BadgeUpdateManager.CreateBadgeUpdaterForApplication().Update(bn)
    End Sub

    'Send Notification
    Private Sub ToastButton_Click(sender As Object, e As RoutedEventArgs)
        Dim toastXml As XmlDocument =
                ToastNotificationManager.GetTemplateContent(ToastTemplateType.ToastText01)
        Dim textNodes As XmlNodeList = toastXml.GetElementsByTagName("text")
        textNodes(0).InnerText = "Your author has something to say. Again."

        Dim tn As ToastNotification = New ToastNotification(toastXml)
        ToastNotificationManager.CreateToastNotifier().Show(tn)
    End Sub
End Class
