﻿Imports Windows.Storage
Imports Windows.Storage.Search
Imports Windows.Storage.Pickers
Imports Windows.Storage.Streams
Imports Windows.UI.Xaml.Media.Imaging

Public NotInheritable Class MainPage
    Inherits Page

    Public ReadOnly Property NavigationHelper As Common.NavigationHelper
        Get
            Return Me._navigationHelper
        End Get
    End Property
    Private _navigationHelper As Common.NavigationHelper

    Public ReadOnly Property DefaultViewModel As Common.ObservableDictionary
        Get
            Return Me._defaultViewModel
        End Get
    End Property
    Private _defaultViewModel As New Common.ObservableDictionary()

    Public Sub New()
        InitializeComponent()
        Me._navigationHelper = New Common.NavigationHelper(Me)
        AddHandler Me._navigationHelper.LoadState, AddressOf NavigationHelper_LoadState
        AddHandler Me._navigationHelper.SaveState, AddressOf NavigationHelper_SaveState
    End Sub

    Private Async Sub NavigationHelper_LoadState(sender As Object, e As Common.LoadStateEventArgs)
        'If the application is launched from an image file, display it.
        'Else, if an image file has been previously saved in Local Settings, display it.
        Dim imageFile As StorageFile = TryCast(e.NavigationParameter, StorageFile)
        If Not imageFile Is Nothing Then
            Await SetSource(imageFile)
        Else

            Dim localSettings As ApplicationDataContainer = ApplicationData.Current.LocalSettings
            If Not localSettings.Values("imageSource") Is Nothing Then
                Dim filePath As String = DirectCast(localSettings.Values("imageSource"), String)
                imageFile = Await StorageFile.GetFileFromPathAsync(filePath)
                Await SetSource(imageFile)
            End If
        End If

    End Sub

    Private Sub NavigationHelper_SaveState(sender As Object, e As Common.SaveStateEventArgs)

    End Sub

#Region "NavigationHelper registration"

    ''' The methods provided in this section are simply used to allow
    ''' NavigationHelper to respond to the page's navigation methods.
    ''' 
    ''' Page specific logic should be placed in event handlers for the  
    ''' <see cref="Common.NavigationHelper.LoadState"/>
    ''' and <see cref="Common.NavigationHelper.SaveState"/>.
    ''' The navigation parameter is available in the LoadState method 
    ''' in addition to page state preserved during an earlier session.

    Protected Overrides Sub OnNavigatedTo(e As NavigationEventArgs)
        _navigationHelper.OnNavigatedTo(e)
    End Sub

    Protected Overrides Sub OnNavigatedFrom(e As NavigationEventArgs)
        _navigationHelper.OnNavigatedFrom(e)
    End Sub

#End Region

    'Display a specific image that is located in the Pictures Library
    Private Async Sub OpenLogoButton_Click(sender As Object, e As RoutedEventArgs) Handles OpenLogoButton.Click
        Dim picFolder As StorageFolder = KnownFolders.PicturesLibrary
        Dim logoFile As StorageFile = Await picFolder.GetFileAsync("FluentLogo.png") 'Add a picture with this name to PicturesLibrary first!!!
        Await SetSource(logoFile)
    End Sub

    'Display image file and save image in Local Settings
    Private Async Function SetSource(file As StorageFile) As Task
        If Not file Is Nothing Then
            Dim bitmap As BitmapImage = New BitmapImage()
            Using fileStream As IRandomAccessStream =
                Await file.OpenAsync(FileAccessMode.Read)
                Await bitmap.SetSourceAsync(fileStream)
                logoImage.Source = bitmap
            End Using

            Dim localSettings As ApplicationDataContainer = ApplicationData.Current.LocalSettings
            localSettings.Values("imageSource") = file.Path
        End If
    End Function

    'Use File Picker to retrieve image.  Display it and save in Local Settings
    Private Async Sub OpenPickerButton_Click(sender As Object, e As RoutedEventArgs) Handles OpenPickerButton.Click
        Dim picker As FileOpenPicker = New FileOpenPicker()
        picker.ViewMode = PickerViewMode.Thumbnail
        picker.SuggestedStartLocation = PickerLocationId.PicturesLibrary
        picker.FileTypeFilter.Add(".png")
        picker.FileTypeFilter.Add(".jpg")

        Dim file As StorageFile = Await picker.PickSingleFileAsync()
        Await SetSource(file)
    End Sub

    'Use the Folder Picker to query its contents
    Private Async Sub OpenFolderButton_Click(sender As Object, e As RoutedEventArgs) Handles OpenFolderButton.Click
        Dim picker As FolderPicker = New FolderPicker()
        picker.ViewMode = PickerViewMode.Thumbnail
        picker.SuggestedStartLocation = PickerLocationId.PicturesLibrary
        picker.FileTypeFilter.Add(".jpg")
        picker.FileTypeFilter.Add(".png")
        Dim folder As StorageFolder = Await picker.PickSingleFolderAsync()
        DefaultViewModel("folder") = folder
    End Sub

    'Query the contents of the Pictures Library
    Private Async Sub QueryPicturesLibrary_Click(sender As Object, e As RoutedEventArgs) Handles QueryPicturesLibrary.Click
        Dim folder As StorageFolder = KnownFolders.PicturesLibrary
        Dim result As StorageFolderQueryResult = folder.CreateFolderQuery(CommonFolderQuery.GroupByType)
        Dim folderList As IReadOnlyList(Of StorageFolder) = Await result.GetFoldersAsync()
        Dim sb As System.Text.StringBuilder = New System.Text.StringBuilder()
        For Each f As StorageFolder In folderList
            Dim fileList As IReadOnlyList(Of StorageFile) = Await f.GetFilesAsync()
            sb.AppendLine(f.Name + "s: " + fileList.Count.ToString())
        Next

        QueryText.Text = sb.ToString()
    End Sub

    
End Class
