﻿Imports Windows.ApplicationModel.DataTransfer
Imports Windows.Storage

''' <summary>
''' A basic page that provides characteristics common to most applications.
''' </summary>
Public NotInheritable Class MainPage
    Inherits Page

    ''' <summary>
    ''' NavigationHelper is used on each page to aid in navigation and 
    ''' process lifetime management
    ''' </summary>
    Public ReadOnly Property NavigationHelper As Common.NavigationHelper
        Get
            Return Me._navigationHelper
        End Get
    End Property
    Private _navigationHelper As Common.NavigationHelper

    ''' <summary>
    ''' This can be changed to a strongly typed view model.
    ''' </summary>
    Public ReadOnly Property DefaultViewModel As Common.ObservableDictionary
        Get
            Return Me._defaultViewModel
        End Get
    End Property
    Private _defaultViewModel As New Common.ObservableDictionary()

    Public Sub New()

        InitializeComponent()
        Me._navigationHelper = New Common.NavigationHelper(Me)
        AddHandler Me._navigationHelper.LoadState, AddressOf NavigationHelper_LoadState
        AddHandler Me._navigationHelper.SaveState, AddressOf NavigationHelper_SaveState

        Dim dtm As DataTransferManager = DataTransferManager.GetForCurrentView()
        AddHandler dtm.DataRequested, AddressOf ShareDataRequested

        AddHandler ApplicationData.Current.DataChanged, AddressOf OnDataChanged
        UpdateDisplay()


    End Sub

   
    Private Sub NavigationHelper_LoadState(sender As Object, e As Common.LoadStateEventArgs)

    End Sub

   
    Private Sub NavigationHelper_SaveState(sender As Object, e As Common.SaveStateEventArgs)

    End Sub

#Region "NavigationHelper registration"

    ''' The methods provided in this section are simply used to allow
    ''' NavigationHelper to respond to the page's navigation methods.
    ''' 
    ''' Page specific logic should be placed in event handlers for the  
    ''' <see cref="Common.NavigationHelper.LoadState"/>
    ''' and <see cref="Common.NavigationHelper.SaveState"/>.
    ''' The navigation parameter is available in the LoadState method 
    ''' in addition to page state preserved during an earlier session.

    Protected Overrides Sub OnNavigatedTo(e As NavigationEventArgs)
        _navigationHelper.OnNavigatedTo(e)
    End Sub

    Protected Overrides Sub OnNavigatedFrom(e As NavigationEventArgs)
        _navigationHelper.OnNavigatedFrom(e)
    End Sub

#End Region


    Sub ShareDataRequested(sender As DataTransferManager, args As DataRequestedEventArgs)
        Dim request As DataRequest = args.Request
        request.Data.Properties.Title = "Sharing Newbie"
        request.Data.Properties.Description = "Our first example."
        request.Data.SetText(Me.SharedText.Text)
    End Sub


    Private Sub ShowShare_Click(sender As Object, e As RoutedEventArgs)
        DataTransferManager.ShowShareUI()
    End Sub


    Async Sub OnDataChanged(sender As ApplicationData, args As Object)
        Await Me.Dispatcher.RunAsync(Windows.UI.Core.CoreDispatcherPriority.Normal, AddressOf UpdateDisplay)
    End Sub

    Sub UpdateDisplay()
        Dim settingsData As ApplicationDataContainer = ApplicationData.Current.LocalSettings
        If settingsData.Values.ContainsKey("receivedText") Then
            Me.ReceivedText.Text = TryCast(settingsData.Values("receivedText"), String)
        End If

        If (settingsData.Values.ContainsKey("setting")) Then
            Me.SettingText.Text = "The custom setting is " + TryCast(settingsData.Values("setting"), String)
        Else
            Me.SettingText.Text = "The custom setting is off"
        End If

    End Sub

End Class
